chrome.runtime.onMessage.addListener(async (message, sender, sendResponse) => {
  if (message.action === 'insertUrls') {
    const targetType = document.querySelector(
        'input[name="target_type"]:checked'
    )?.value || 'bots';

    const targetOptionsDiv = document.querySelector('.pr-target-options.visible');
    if (!targetOptionsDiv) return;

    // 创建持久状态容器
    const statusContainer = document.createElement('div');
    statusContainer.style.marginTop = '15px';
    statusContainer.style.borderTop = '1px solid #eee';
    statusContainer.style.paddingTop = '10px';

    // 进度计数器
    const progressCounter = document.createElement('div');
    progressCounter.className = 'progress-counter';
    progressCounter.style.color = '#666';
    progressCounter.style.marginBottom = '8px';

    // 错误列表容器
    const errorList = document.createElement('div');
    errorList.className = 'error-list';
    errorList.style.maxHeight = '200px';
    errorList.style.overflowY = 'auto';

    statusContainer.append(progressCounter, errorList);
    targetOptionsDiv.appendChild(statusContainer);

    const placeholder = targetType === 'bots'
        ? 't.me bot URL'
        : 't.me channel URL';

    const inputDiv = document.querySelector(
        `.input[data-placeholder="${placeholder}"]`
    );

    if (!inputDiv) return;
    inputDiv.innerHTML = '';

    const total = message.urls.length;
    let current = 0;
    const failedUrls = [];

    for (const url of message.urls) {
      current++;
      progressCounter.textContent = `正在处理：${current}/${total} (${Math.round((current/total)*100)}%)`;

      // 插入URL元素
      const div = document.createElement('div');
      div.textContent = url.trim();
      inputDiv.appendChild(div);

      ['input', 'change'].forEach(eventType => {
        inputDiv.dispatchEvent(new Event(eventType, { bubbles: true }));
      });

      await new Promise(r => setTimeout(r, 300));

      inputDiv.focus();
      inputDiv.dispatchEvent(new Event('focus', { bubbles: true }));
      await new Promise(r => setTimeout(r, 200));

      const enterEvent = new KeyboardEvent('keydown', {
        key: 'Enter',
        code: 'Enter',
        keyCode: 13,
        bubbles: true,
        composed: true
      });
      inputDiv.dispatchEvent(enterEvent);

      // 等待结果处理
      await new Promise(r => setTimeout(r, 500));

      // 清空前次错误
      const errorMsg = document.querySelector('.pr-form-control-msg-text');
      if (errorMsg) {
        const originalText = errorMsg.textContent;
        errorMsg.textContent = '';

        await new Promise(r => setTimeout(r, 500)); // 等待错误提示更新

        // 错误检测
        if (originalText.trim()) {
          const errorItem = document.createElement('div');
          errorItem.style.color = '#dc3545';
          errorItem.style.margin = '3px 0';
          errorItem.innerHTML = `
            <span style="font-weight:500">⚠️ ${url}</span>
            <div style="margin-left:10px;font-size:0.9em">错误原因：${originalText}</div>
          `;
          errorList.appendChild(errorItem);

          // 保持滚动位置可见
          errorList.scrollTop = errorList.scrollHeight;

          failedUrls.push(url);
        }
      }

      inputDiv.innerHTML = '';
    }

    // 最终状态显示
    progressCounter.innerHTML = failedUrls.length > 0
        ? `<span style="color:#dc3545">⚠ 完成 ${total - failedUrls.length}/${total} 个（失败 ${failedUrls.length} 个）</span>`
        : `<span style="color:#28a745">✅ 全部完成 ${total} 个链接</span>`;

    // 显示失败清单
    if (failedUrls.length > 0) {
      const retryBtn = document.createElement('button');
      retryBtn.textContent = '';
      retryBtn.style.marginTop = '10px';
      retryBtn.style.padding = '5px 12px';
      retryBtn.style.background = '000';
      retryBtn.style.border = 'none';
      retryBtn.style.borderRadius = '4px';
      retryBtn.onclick = () => {
        chrome.runtime.sendMessage({
          action: 'insertUrls',
          urls: failedUrls
        });
        statusContainer.remove();
      };
      statusContainer.appendChild(retryBtn);
    }

    inputDiv.dispatchEvent(new Event('blur', { bubbles: true }));
    inputDiv.classList.remove('empty');
    inputDiv.removeAttribute('data-value');
  }
});
